componenttools.yield_components_grouped_by_prolated_duration
============================================================

.. autofunction:: abjad.tools.componenttools.yield_components_grouped_by_prolated_duration.yield_components_grouped_by_prolated_duration
